; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
;
[Command] ;Two quarter circles forward + y
name = "2QCF_x"
command = ~D, DF, F, D, DF, F, x
time = 25

[Command] ;Two quarter circles forward + y
name = "2QCF_x"
command = ~D, DF, F, D, DF, F, y
time = 25

[Command] ;Two quarter circles forward + y
name = "2QCF_x"
command = ~D, DF, F, D, DF, F, z
time = 25

[Command] ;Two quarter circles forward + y
name = "2QCB_x"
command = ~D, DB, B, D, DB, B, x
time = 25

[Command] ;Two quarter circles forward + y
name = "2QCB_x"
command = ~D, DB, B, D, DB, B, y
time = 25

[Command] ;Two quarter circles forward + y
name = "2QCB_x"
command = ~D, DB, B, D, DB, B, z
time = 25

[Command] ;Two quarter circles forward + y
name = "2QCF_k"
command = ~D, DF, F, D, DF, F, a
time = 25

[Command] ;Two quarter circles forward + y
name = "2QCF_k"
command = ~D, DF, F, D, DF, F, b
time = 25

[Command] ;Two quarter circles forward + y
name = "2QCF_k"
command = ~D, DF, F, D, DF, F, c
time = 25

[Command] ;Two quarter circles forward + y
name = "2QCB_k"
command = ~D, DB, B, D, DB, B, a
time = 25

[Command] ;Two quarter circles forward + y
name = "2QCB_k"
command = ~D, DB, B, D, DB, B, b
time = 25

[Command] ;Two quarter circles forward + y
name = "2QCB_k"
command = ~D, DB, B, D, DB, B, c
time = 25

[Command]
name = "QCFp_EX1"
command = ~D, DF, F, x+y

[Command]
name = "QCFp_EX2"
command = ~D, DF, F, y+z

[Command]
name = "QCFp_EX3"
command = ~D, DF, F, x+z

[Command]
name = "QCFp_EX"
command = ~D, DF, F, x+y

[Command]
name = "QCFp_EX"
command = ~D, DF, F, y+z

[Command]
name = "QCFp_EX"
command = ~D, DF, F, x+z

[Command]
name = "DPp_EX"
command = ~F, D, DF, x+y

[Command]
name = "DPp_EX"
command = ~F, D, DF, y+z

[Command]
name = "DPp_EX"
command = ~F, D, DF, x+z

[Command]
name = "QCFk_EX"
command = ~D, DF, F, a+b

[Command]
name = "QCFk_EX"
command = ~D, DF, F, a+c

[Command]
name = "QCFk_EX"
command = ~D, DF, F, b+c

[Command]
name = "HCBk_EX"
command = ~F, DF, D, DB, B, a+b
time = 17

[Command]
name = "HCBk_EX"
command = ~F, DF, D, DB, B, b+c
time = 17

[Command]
name = "HCBk_EX"
command = ~F, DF, D, DB, B, a+c
time = 17

[Command]
name = "DDk_EX"
command = ~D, D, a+b

[Command]
name = "DDk_EX"
command = ~D, D, a+c

[Command]
name = "DDk_EX"
command = ~D, D, b+c

[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCF_z"
command = ~D, DF, F, z

[Command]
name = "QCF_a"
command = ~D, DF, F, a

[Command]
name = "QCF_b"
command = ~D, DF, F, b

[Command]
name = "QCF_c"
command = ~D, DF, F, c

[Command]
name = "DD_a"
command = ~D, D, a
time = 10
[Command]
name = "DD_b"
command = ~D, D, b
time = 10
[Command]
name = "DD_c"
command = ~D, D, c
time = 10
[Command]
name = "HCB_a"
command = ~F, DF, D, DB, B, a
time = 17

[Command]
name = "HCB_b"
command = ~F, DF, D, DB, B, b
time = 17

[Command]
name = "HCB_c"
command = ~F, DF, D, DB, B, c
time = 17

[Command]
name = "DP_x"
command = ~F, D, DF, x

[Command]
name = "DP_y"
command = ~F, D, DF, y

[Command]
name = "DP_z"
command = ~F, D, DF, z

[Command]
name = "DP_a"
command = ~F, D, DF, a

[Command]
name = "DP_b"
command = ~F, D, DF, b

[Command]
name = "DP_c"
command = ~F, D, DF, c

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

[Command]
name = "hparry"
command = F
time = 1

[Command]
name = "lparry"
command = D
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

[Command]
name = "holdp"
command = /x
time = 1

[Command]
name = "holdp"
command = /y
time = 1

[Command]
name = "holdp"
command = /z
time = 1


;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.

[Statedef -1]

; Hell Talons
[State -1]
type = ChangeState
value = 3000
triggerall = stateno !=3000
triggerall = power >= 1000 && statetype !=A
triggerall = command = "2QCF_x" 
trigger1 = ctrl = 1
trigger2 = hitdefattr = SCA, NA, SA, HA
trigger2 = movecontact
trigger3 = NumHelper(11000)
trigger3 = helper(11000), movecontact
trigger4 = NumHelper(3012)
trigger4 = helper(3012), movecontact

; Hell Talons
[State -1]
type = ChangeState
value = 3020
triggerall = stateno !=[3020,3022]
triggerall = power >= 1000 && statetype !=A
triggerall = command = "2QCB_x" 
trigger1 = ctrl = 1
trigger2 = hitdefattr = SCA, NA, SA, HA
trigger2 = movecontact
trigger3 = NumHelper(11000)
trigger3 = helper(11000), movecontact
trigger4 = NumHelper(3012)
trigger4 = helper(3012), movecontact
trigger5 = NumHelper(3005)
trigger5 = helper(3005), movecontact

; Jade Blitz
[State -1]
type = ChangeState
value = 3030
triggerall = stateno !=[3030,3031]
triggerall = power >= 1000 && statetype !=A
triggerall = command = "2QCF_k" 
trigger1 = ctrl = 1
trigger2 = hitdefattr = SCA, NA, SA, HA
trigger2 = movecontact
trigger3 = NumHelper(11000)
trigger3 = helper(11000), movecontact
trigger4 = NumHelper(3012)
trigger4 = helper(3012), movecontact
trigger5 = NumHelper(3005)
trigger5 = helper(3005), movecontact

; Hell Talons
[State -1]
type = ChangeState
value = 3010
triggerall = stateno !=3010
triggerall = power >= 1000 && statetype !=A
triggerall = command = "2QCB_k" 
trigger1 = ctrl = 1
trigger2 = hitdefattr = SCA, NA, SA, HA
trigger2 = movecontact
trigger3 = NumHelper(11000)
trigger3 = helper(11000), movecontact
trigger4 = NumHelper(3005)
trigger4 = helper(3005), movecontact

;Hadoken_EX
[State -1]
type = ChangeState
value = 2020
triggerall = power >= 500
triggerall = command = "DPp_EX"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact

;Hadoken_EX
[State -1]
type = ChangeState
value = 2000
triggerall = !NumHelper(11000)
triggerall = power >= 500
triggerall = command = "QCFp_EX3"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact

;Hadoken_EX
[State -1]
type = ChangeState
value = 2010
triggerall = power >= 500
triggerall = command = "QCFk_EX"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact

;Hadoken_EX
[State -1]
type = ChangeState
value = 2001
triggerall = !NumHelper(11000)
triggerall = power >= 500
triggerall = command = "QCFp_EX1"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact

;Hadoken_EX
[State -1]
type = ChangeState
value = 2002
triggerall = !NumHelper(11000)
triggerall = power >= 500
triggerall = command = "QCFp_EX2"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact

;Hadoken_EX
[State -1]
type = ChangeState
value = 2030
triggerall = !NumHelper(11000)
triggerall = power >= 500
triggerall = command = "HCBk_EX"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact

;Hadoken_EX
[State -1]
type = ChangeState
value = 2050
triggerall = !var(5) && !var(6) ;Not in phase or phase recovery
triggerall = power >= 500
triggerall = command = "DDk_EX"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact



;Shadow Slip
[State -1]
type = ChangeState
value = 1040
triggerall = command = "DP_a"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact



;---------------------------------------------------------------------------
;Shadow Slip
[State -1]
type = ChangeState
value = 1041
triggerall = command = "DP_b"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact



;---------------------------------------------------------------------------
;Shadow Slip
[State -1]
type = ChangeState
value = 1042
triggerall = command = "DP_c"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact



;Don't Touch Me!
[State -1]
type = ChangeState
value = 1020
triggerall = command = "DP_x" 
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact

;Don't Touch Me!
[State -1]
type = ChangeState
value = 1021
triggerall = command = "DP_y" 
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact

;Don't Touch Me!
[State -1]
type = ChangeState
value = 1022
triggerall = command = "DP_z"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact

;Kikkoken_X
[State -1]
type = ChangeState
value = 1000
triggerall = !NumHelper(11000)
triggerall = command = "QCF_x"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact

;---------------------------------------------------------------------------
;Kikkoken_Y
[State -1]
type = ChangeState
value = 1001
triggerall =!NumHelper(11000)
triggerall = command = "QCF_y"
triggerall = numproj = 0
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact



;---------------------------------------------------------------------------
;Kikkoken_Z
[State -1]
type = ChangeState
value = 1002
triggerall = !NumHelper(11000)
triggerall = numproj = 0
triggerall = command = "QCF_z"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact

;Kikkoken_X
[State -1]
type = ChangeState
value = 1030
triggerall = !NumHelper(11000)
triggerall = command = "HCB_a"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact

;---------------------------------------------------------------------------
;Kikkoken_Y
[State -1]
type = ChangeState
value = 1031
triggerall =!NumHelper(11000)
triggerall = command = "HCB_b"
triggerall = numproj = 0
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact



;---------------------------------------------------------------------------
;Kikkoken_Z
[State -1]
type = ChangeState
value = 1032
triggerall = !NumHelper(11000)
triggerall = numproj = 0
triggerall = command = "HCB_c"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact

;Kikkoken_X
[State -1]
type = ChangeState
value = 1010
triggerall = command = "QCF_a"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact

;---------------------------------------------------------------------------
;Kikkoken_Y
[State -1]
type = ChangeState
value = 1011
triggerall = command = "QCF_b"
triggerall = numproj = 0
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact



;---------------------------------------------------------------------------
;Kikkoken_Z
[State -1]
type = ChangeState
value = 1012
triggerall = numproj = 0
triggerall = command = "QCF_c"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact

;Phase Out
[State -1]
type = ChangeState
value = 1050
triggerall = !var(5) && !var(6) ;Not in phase or phase recovery
triggerall = command = "DD_a"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact

;---------------------------------------------------------------------------
;Phase Out
[State -1]
type = ChangeState
value = 1051
triggerall = !var(5) && !var(6) ;Not in phase or phase recovery
triggerall = command = "DD_b"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact



;---------------------------------------------------------------------------
;Phase Out
[State -1]
type = ChangeState
value = 1052
triggerall = !var(5) && !var(6) ;Not in phase or phase recovery
triggerall = command = "DD_c"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) 
trigger2 = movecontact

;Blowout
[State -1, Kung Fu Throw]
type = ChangeState
value = 800 
triggerall = (command = "y") || (command = "z")
triggerall = statetype !=A
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd" && (statetype = S)
trigger1 = p2bodydist X < 6
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback" && (statetype = S)
trigger2 = p2bodydist X < 8
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H
;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;Standing Light Punch
[State -1]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200 && time > 4
trigger3 = stateno = 400 && time > 4

;Standing Medium Punch
[State -1]
type = ChangeState
value = 210
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = 200 || stateno = 230) && movecontact
trigger3 = (stateno = 400 || stateno = 430) && movecontact
;---------------------------------------------------------------------------
;Standing Heavy Punch
[State -1]
type = ChangeState
value = 220
triggerall = command = "z"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = 200 || stateno = 230) && movecontact
trigger3 = (stateno = 400 || stateno = 430) && movecontact

;Standing Light Kick
[State -1]
type = ChangeState
value = 230
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = 200 || stateno = 400) && movecontact && palno = 12

;Standing Medium Punch
[State -1]
type = ChangeState
value = 240
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = 200 || stateno = 230) && movecontact
trigger3 = (stateno = 400 || stateno = 430) && movecontact
;---------------------------------------------------------------------------
;Standing Heavy Punch
[State -1]
type = ChangeState
value = 250
triggerall = command = "c"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = 200 || stateno = 230) && movecontact
trigger3 = (stateno = 400 || stateno = 430) && movecontact

;Standing Light Punch
[State -1]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = (stateno = 200 || stateno = 400) && time > 4
trigger3 = stateno = 430 && time > 4

;Standing Medium Punch
[State -1]
type = ChangeState
value = 410
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = (stateno = 200 || stateno = 230) && movecontact
trigger3 = (stateno = 400 || stateno = 430) && movecontact
;---------------------------------------------------------------------------
;Standing Heavy Punch
[State -1]
type = ChangeState
value = 420
triggerall = command = "z"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = (stateno = 200 || stateno = 230) && movecontact
trigger3 = (stateno = 400 || stateno = 430) && movecontact

;Standing Light Kick
[State -1]
type = ChangeState
value = 430
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = (stateno = 200 || stateno = 400) && time > 4
trigger3 = stateno = 430 && time > 4

;Standing Medium Punch
[State -1]
type = ChangeState
value = 440
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = (stateno = 200 || stateno = 230) && movecontact
trigger3 = (stateno = 400 || stateno = 430) && movecontact
;---------------------------------------------------------------------------
;Standing Heavy Punch
[State -1]
type = ChangeState
value = 450
triggerall = command = "c"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = (stateno = 200 || stateno = 230) && movecontact
trigger3 = (stateno = 400 || stateno = 430) && movecontact

;Jumping Light Punch (neutral)
[State -1]
type = ChangeState
value = 600
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jumping Medium Punch (neutral)
[State -1]
type = ChangeState
value = 610
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = (stateno = 600 || stateno = 630) && movecontact
;---------------------------------------------------------------------------
;Jumping Heavy Punch (neutral)
[State -1]
type = ChangeState
value = 620
triggerall = command = "z"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = (stateno = 600 || stateno = 630) && movecontact
;---------------------------------------------------------------------------
;Jumping Light Kick (neutral)
[State -1]
type = ChangeState
value = 630
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jumping Medium Kick (neutral)
[State -1]
type = ChangeState
value = 640
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = (stateno = 600 || stateno = 630) && movecontact
;---------------------------------------------------------------------------
;Jumping Heavy Kick (neutral)
[State -1]
type = ChangeState
value = 650
triggerall = command = "c"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = (stateno = 600 || stateno = 630) && movecontact

;---------------------------------------------------------------------------

;Taunt
;
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl

;-------------------
;MEE Template Files
;   provided by
;  Kitsune Sniper
;       ***
; Thanks, Kitsune!
;-------------------
